# Table of Contents

- [sap-modeling-best-practices](<./sap-modeling-best-practices.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP Modeling Best Practices](<./SAP-Modeling-Best-Practices.md>)
  - [Overview](<./SAP-Modeling-Best-Practices/Overview.md>)
  - [Relevant Use Cases](<./SAP-Modeling-Best-Practices/Relevant-Use-Cases.md>)
  - [Related Resources](<./SAP-Modeling-Best-Practices/Related-Resources.md>)
